@@ -83,11 +83,11 @@ class GARetinaHead(GuidedAnchorHead):
             deform_groups=self.deform_groups)
         self.retina_cls = MaskedConv2d(
             self.feat_channels,
-            self.num_anchors * self.cls_out_channels,
+            self.num_base_priors * self.cls_out_channels,
             3,
             padding=1)
         self.retina_reg = MaskedConv2d(
-            self.feat_channels, self.num_anchors * 4, 3, padding=1)
+            self.feat_channels, self.num_base_priors * 4, 3, padding=1)
 
     def forward_single(self, x):
         """Forward feature map of a single scale level."""
